@@ -28,10 +28,10 @@ extern struct scrimage
 	*DesiredScreen,		/* what we want */
 	*PhysScreen;		/* what we got */
 
-extern bool	UpdMesg;	/* update the message line */
+extern jbool	UpdMesg;	/* update the message line */
 
-extern bool
-	chkmail proto((bool force));
+extern jbool
+	chkmail proto((jbool force));
 
 extern int
 	calc_pos proto((char *lp,int c_char));
@@ -41,7 +41,7 @@ extern int
 extern void
 	ChkWindows proto((LinePtr line1,LinePtr line2)),
 	ChkWinLines proto((void)),
-	DrawMesg proto((bool abortable)),
+	DrawMesg proto((jbool abortable)),
 	message proto((const char *)),
 	TOstart proto((const char *name)),
 	TOstop proto((void)),
@@ -51,41 +51,41 @@ extern void
 
 
 #ifdef WINRESIZE
-extern volatile bool
+extern volatile jbool
 	ResizePending;	/* asynch request for screen resize */
 # ifdef WIN32
 extern void ResizeWindow proto((void));
 # endif
 #endif
 
-extern bool
+extern jbool
 	DisabledRedisplay;
 
 #ifdef ID_CHAR
-extern bool
+extern jbool
 	IN_INSmode;
 
 extern void
-	INSmode proto((bool));
+	INSmode proto((jbool));
 #endif /* ID_CHAR */
 
 
 /* Variables: */
 
-extern bool	BriteMode;		/* VAR: make the mode line inverse? */
+extern jbool	BriteMode;		/* VAR: make the mode line inverse? */
 #ifdef UNIX
 extern int	MailInt;		/* VAR: mail check interval */
 extern char	Mailbox[FILESIZE];	/* VAR: mailbox name */
 #endif /* UNIX */
 extern char	ModeFmt[MAXCOLS];	/* VAR: mode line format string */
-extern bool	ScrollAll;		/* VAR: when current line scrolls, scroll whole window? */
+extern jbool	ScrollAll;		/* VAR: when current line scrolls, scroll whole window? */
 extern int	ScrollWidth;		/* VAR: unit of horizontal scrolling */
-extern bool	UseBuffers;		/* VAR: use buffers with Typeout() */
+extern jbool	UseBuffers;		/* VAR: use buffers with Typeout() */
 #ifdef ID_CHAR
-extern bool	UseIC;			/* VAR: whether or not to use i/d char processesing */
+extern jbool	UseIC;			/* VAR: whether or not to use i/d char processesing */
 #endif
-extern bool	VisBell;		/* VAR: use visible bell (if possible) */
-extern bool	MarkHighlighting;	/* VAR: highlight mark when visible */
+extern jbool	VisBell;		/* VAR: use visible bell (if possible) */
+extern jbool	MarkHighlighting;	/* VAR: highlight mark when visible */
 
 /* Commands: */
 extern void
