@@ -65,6 +65,7 @@
 #endif /* MSDOS */
 
 #ifdef WIN32
+# undef Fill /* sigh, used as a field name in some windows header! */
 # undef CR /* sigh, used as a field name in some windows header! */
 # include <windows.h>	/* ??? is this needed? */
 # undef FIONREAD	 /* This is defined but ioctl isn't so we cannot use it. */
@@ -90,13 +91,13 @@ STACK_DECL
 #define MAXBASENAMELEN (1+14+1)
 
 private void
-	UnsetTerm proto((bool)),
-	DoKeys proto((bool firsttime)),
+	UnsetTerm proto((jbool)),
+	DoKeys proto((jbool firsttime)),
 	ShowKeyStrokes proto((void)),
 	jexecpath proto((char *, size_t));
 
 #ifdef NONBLOCKINGREAD
-private void	setblock proto((bool on));
+private void	setblock proto((jbool on));
 #endif
 
 #ifdef POSIX_SIGS
@@ -116,7 +117,7 @@ SIGHANDLERTYPE	handler;
 }
 #endif
 
-bool	TimeDisplayed = YES;	/* is time actually displayed in modeline? */
+jbool	TimeDisplayed = YES;	/* is time actually displayed in modeline? */
 char	JoveFeatures[MAXCOLS];	/* VAR: list of compiled-in features */
 
 #ifdef UNIX
@@ -124,11 +125,11 @@ char	JoveFeatures[MAXCOLS];	/* VAR: list of compiled-in features */
 /* set things up to update the modeline every UpdFreq seconds */
 
 int	UpdFreq = 30;	/* VAR: how often to update modeline */
-bool	InSlowRead = NO;
+jbool	InSlowRead = NO;
 
 void
 SetClockAlarm(unset)
-bool	unset;	/* unset alarm if none needed */
+jbool	unset;	/* unset alarm if none needed */
 {
 	if (TimeDisplayed && UpdFreq != 0)
 		(void) alarm((unsigned) (UpdFreq - (time((time_t *)NULL) % UpdFreq)));
@@ -143,7 +144,7 @@ bool	unset;	/* unset alarm if none needed */
  * is called often enough that it turns out to be self-correcting.
  */
 
-private volatile bool	InWaitChar = NO;
+private volatile jbool	InWaitChar = NO;
 
 /*ARGSUSED*/
 private SIGRESTYPE
@@ -180,7 +181,7 @@ int	UNUSED(junk);	/* passed in on signal; of no interest */
 
 #endif /* UNIX */
 
-bool	stickymsg;	/* the last message should stick around */
+jbool	stickymsg;	/* the last message should stick around */
 
 char	NullStr[] = "";
 jmp_buf	mainjmp;
@@ -243,7 +244,7 @@ int	code;
 #ifdef RECOVER
 	int save_errno = errno;	/* Subtle, but necessary! */
 #endif
-	bool	DelTmps = YES;		/* Usually we delete them. */
+	jbool	DelTmps = YES;		/* Usually we delete them. */
 
 	DisabledRedisplay = YES;
 #ifndef MAC
@@ -254,7 +255,7 @@ int	code;
 #endif
 #ifdef RECOVER
 	if (code != 0) {
-		static bool	Crashing = NO;	/* we are in the middle of crashing */
+		static jbool	Crashing = NO;	/* we are in the middle of crashing */
 
 		if (!Crashing) {
 			Crashing = YES;
@@ -302,7 +303,7 @@ int	code;
 	c = FatalErrorMessage("Fatal interrupt encountered. Abort?");
 #else /* !WIN32 */
 # ifdef PIPEPROCS
-	bool	started;
+	jbool	started;
 # endif
 
 	resetsighandler(SIGINT, handle_sigint);
@@ -353,10 +354,10 @@ private int	nchars = 0;
 
 private void
 setblock(on)	/* turn blocking on or off */
-bool	on;
+jbool	on;
 {
 	static int blockf, nonblockf;
-	static bool	first = YES;
+	static jbool	first = YES;
 
 	if (first) {
 		int flags;
@@ -398,7 +399,7 @@ bool	on;
 
 int	SlowCmd = 0;	/* depth of nesting of slow commands */
 
-bool	InputPending = NO;	/* is there input waiting to be processed? */
+jbool	InputPending = NO;	/* is there input waiting to be processed? */
 
 /* Inputp is used to jam a NUL-terminated string into JOVE's input stream.
  * It is used to feed each line of the joverc file, to fill in the default
@@ -562,7 +563,7 @@ kbd_getch()
 
 /* Returns YES if a character waiting (excluding macro body) */
 
-bool
+jbool
 charp()
 {
 	if (InJoverc != 0 || kbdpeek != EOF || nchars > 0 || Inputp != NULL)
@@ -751,9 +752,9 @@ private char
 	key_strokes[100],
 	*keys_p = key_strokes;
 
-private bool	in_ask_ks;
+private jbool	in_ask_ks;
 
-private volatile bool	slow_keying = NO;	/* for waitchar() */
+private volatile jbool	slow_keying = NO;	/* for waitchar() */
 
 void
 cmd_sync()
@@ -820,7 +821,7 @@ waitchar()
 {
 	ZXchar	c;
 #ifdef WAITCHAR_CURSOR_DOWN
-	bool	oldAsking;
+	jbool	oldAsking;
 	int	oldAskingWidth;
 #endif
 
@@ -913,7 +914,7 @@ SetTerm()
 
 private void
 UnsetTerm(WarnUnwritten)
-bool	WarnUnwritten;
+jbool	WarnUnwritten;
 {
 #ifdef TERMCAP
 # ifdef ID_CHAR
@@ -1006,7 +1007,7 @@ Push()
 	SIGHANDLERTYPE	old_int = setsighandler(SIGINT, SIG_IGN);
 	int	forkerr = 0;
 #  ifdef PIPEPROCS
-	bool	started = kbd_stop();
+	jbool	started = kbd_stop();
 #  endif
 
 	UnsetTerm(YES);
@@ -1066,13 +1067,13 @@ tty_adjust()
 #endif
 }
 
-bool	Interactive = NO;	/* True when we invoke with the command handler? */
+jbool	Interactive = NO;	/* True when we invoke with the command handler? */
 
 ZXchar
 	peekchar = EOF,	/* holds pushed-back getch output */
 	LastKeyStruck;	/* used by SelfInsert and friends */
 
-bool
+jbool
 	MetaKey = NO;		/* VAR: this terminal has a meta key */
 
 void
@@ -1470,14 +1471,14 @@ Recur()
 	DelMark(m);
 }
 
-bool	SaveOnExit = NO;	/* VAR: offer to save buffers on exit */
+jbool	SaveOnExit = NO;	/* VAR: offer to save buffers on exit */
 
 private int	iniargc;	/* main sets these for DoKeys() */
 private char	**iniargv;
 
 private void
 DoKeys(firsttime)
-bool	firsttime;
+jbool	firsttime;
 {
 	jmp_buf	savejmp;
 
@@ -1584,12 +1585,12 @@ int	UNUSED(junk);	/* passed in when invoked by a signal; of no interest */
 }
 #endif /* WINRESIZE */
 
-private bool
+private jbool
 carefulcpy(to, from, maxsize, mess, raw)
 char	*to,*from;
 size_t	maxsize;
 char	*mess;
-bool	raw;
+jbool	raw;
 {
 	if (from != NULL) {
 		const char	*ugh;
@@ -1617,8 +1618,8 @@ bool	raw;
 
 private void
 dojovercs(dosys, dousr)
-bool	dosys;
-bool	dousr;
+jbool	dosys;
+jbool	dousr;
 {
 	char	Joverc[FILESIZE];
 
@@ -2054,11 +2055,7 @@ char	*argv[];
 }
 
 #ifdef PNAME_SYSCTL_OID
-
-/*
- * FreeBSD, NetBSD.  Includes stdbool, so must be after all
- * the uses of the Jove bool type, sigh!
- */
+/* FreeBSD, NetBSD */
 # include <sys/sysctl.h>
 #endif
 
