@@ -82,7 +82,7 @@ extern FILE	*popen proto((const char *, const char *));
 /* The parameter of getpwuid is widened uid_t,
  * but there no easy portable way to write this
  */
-extern struct passwd *getpwuid(/*widened uid_t*/);
+extern struct passwd *getpwuid proto((uid_t/*widened uid_t*/));
 
 #  ifdef USE_UNAME
 extern int	uname proto((struct utsname *));
@@ -113,8 +113,8 @@ private long	Nchars,
 private char	tty[] = "/dev/tty";
 private const char	*tmp_dir = TMPDIR;
 private uid_t	UserID;
-private bool	Verbose = NO;
-private bool	Debug = NO;
+private jbool	Verbose = NO;
+private jbool	Debug = NO;
 private FILE	*dfp;
 private const char *RecDir = RECDIR;
 
@@ -313,7 +313,7 @@ private const char	*CurDir;
  * out of them.
  */
 
-private bool	add_name proto((char *));
+private jbool	add_name proto((char *));
 
 private void
 free_files() {
@@ -344,7 +344,7 @@ const char	*dirname;
 		freedir(&nmptr, nentries);
 }
 
-private bool
+private jbool
 add_name(fname)
 char *fname;
 {
@@ -620,11 +620,11 @@ char	*dest;
 	}
 }
 
-private bool
+private jbool
 isopt(args, str, needval)
 register char	**args,
 		*str;
-bool		needval;
+jbool		needval;
 {
 	char *cp = *args;
 	if (Debug)
